@@ -20,6 +20,10 @@
 #ifndef KCMREGISTRY_H
 #define KCMREGISTRY_H
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <tqstring.h>
 
 #include <tdelocale.h>
@@ -42,19 +46,13 @@ struct KCMRegistryEntry
 
 KCMRegistryEntry KCMRegistry[] =
 {
-    { "Nettools",
-      i18n( "Uses the tools from the nettool packge like ifconfig, "    \
-            "iwconfig and route to read the necessary information "     \
-            "from the ouput of these commands.\n"                       \
-            "This backend works rather stable but causes a relativly "  \
-            "high CPU load." ) },
-    { "Sys",
-      i18n( "Uses the sys filesystem available in 2.6 kernels and "     \
-            "direct system calls to the Linux kernel.\n"                \
-            "This backend is rather new, so expect minor problems. "    \
-            "As an advantage this backend should reduce the CPU load "  \
-            "and should not access the harddisc while gathering "       \
-            "information." ) },
+    { "Sys", i18n( "Uses the sys filesystem available in 2.6 kernels and " \
+                   "direct system calls to the Linux kernel." ) },
+#if defined( WITH_NETTOOLS )
+    { "Nettools", i18n( "Uses the tools from the net-tools package like ifconfig, " \
+                        "iwconfig and route to read the necessary information "     \
+                        "from the ouput of these commands.") },
+#endif
     { TQString(), TQString() }
 };
 
