@@ -43,9 +43,9 @@ InterfaceStatisticsDialog::InterfaceStatisticsDialog( Interface* interface, TQWi
     setIcon( SmallIcon( "knemo" ) );
     setCaption( interface->getName() + " " + i18n( "Statistics" ) );
 
-    connect( buttonClearDaily, TQT_SIGNAL( clicked() ), TQT_SIGNAL( clearDailyStatisticsClicked() ) );
-    connect( buttonClearMonthly, TQT_SIGNAL( clicked() ), TQT_SIGNAL( clearMonthlyStatisticsClicked() ) );
-    connect( buttonClearYearly, TQT_SIGNAL( clicked() ), TQT_SIGNAL( clearYearlyStatisticsClicked() ) );
+    connect( buttonClearDaily, TQ_SIGNAL( clicked() ), TQ_SIGNAL( clearDailyStatisticsClicked() ) );
+    connect( buttonClearMonthly, TQ_SIGNAL( clicked() ), TQ_SIGNAL( clearMonthlyStatisticsClicked() ) );
+    connect( buttonClearYearly, TQ_SIGNAL( clicked() ), TQ_SIGNAL( clearYearlyStatisticsClicked() ) );
 }
 
 InterfaceStatisticsDialog::~InterfaceStatisticsDialog()
