@@ -58,7 +58,7 @@ KNemoDaemon::KNemoDaemon( const TQCString& name )
     // select the backend from the config file
     TDEConfig* config = new TDEConfig( "knemorc", true );
     config->setGroup( "General" );
-    mBackendName = config->readEntry( "Backend", "Nettools" );
+    mBackendName = config->readEntry( "Backend", "Sys" );
     delete config;
 
     bool foundBackend = false;
@@ -74,14 +74,14 @@ KNemoDaemon::KNemoDaemon( const TQCString& name )
 
     if ( !foundBackend )
     {
-        i = 0; // use the first backend (Nettools)
+        i = 0; // use the first backend (Sys)
     }
     mBackend = ( *DaemonRegistry[i].function )( mInterfaceDict );
 
     mInterfaceDict.setAutoDelete( true );
 
     mPollTimer = new TQTimer();
-    connect( mPollTimer, TQT_SIGNAL( timeout() ), this, TQT_SLOT( updateInterfaces() ) );
+    connect( mPollTimer, TQ_SIGNAL( timeout() ), this, TQ_SLOT( updateInterfaces() ) );
     mPollTimer->start( mGeneralData.pollInterval * 1000 );
 }
 
@@ -195,7 +195,7 @@ void KNemoDaemon::reparseConfiguration()
     mPollTimer->changeInterval( mGeneralData.pollInterval * 1000 );
 
     // select the backend from the config file
-    TQString backend = config->readEntry( "Backend", "Nettools" );
+    TQString backend = config->readEntry( "Backend", "Sys" );
 
     if ( mBackendName != backend )
     {
